<?php
/**
 * HomePage Posts
 *
 * @package Beauty
 */

$features = beauty_get_settings( 'mts_featured_categories' );
if ( empty( $features ) ) {
	return;
}
foreach ( $features as $feature ) :
	$title        = isset( $feature['mts_featured_title'] ) ? $feature['mts_featured_title'] : 'No Title';
	$posts_layout = isset( $feature['mts_thumb_layout'] ) ? $feature['mts_thumb_layout'] : '';
	if ( 'layout-default' === $posts_layout ) {
		$posts_layout = 'default';
	}
	$unique_id = isset( $feature['unique_id'] ) ? $feature['unique_id'] : '';

	$menus[ 'homepage-' . $unique_id ] = array(
		'title' => $title,
		// translators: description.
		'desc'  => sprintf( wp_kses_post( __( 'From here, you can control the elements of %s', 'beauty' ) ), $title ),
	);

	$sections[ 'homepage-' . $unique_id ] = array(


		/**
		 * Layout Slider.
		 *
		 * @package Beauty
		 */

		// Section Title.
		( 'layout-slider' === $posts_layout ) ? array(
			'id'    => 'mts_post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'beauty' ),
		) : null,

		( 'layout-slider' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'beauty' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'beauty' ),
			'std'      => '0',
		) : null,

		( 'layout-slider' === $posts_layout ) ? array(
			'id'         => 'mts_post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'beauty' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'beauty' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'beauty' ),
				'center' => esc_html__( 'Center', 'beauty' ),
				'right'  => esc_html__( 'Right', 'beauty' ),
			),
			'std'        => 'left',
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-slider' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'beauty' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'beauty' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-slider' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'beauty' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'beauty' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '30px',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-slider' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'beauty' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'beauty' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-slider' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'beauty' ),
			'sub_desc'   => esc_html__( 'Select border', 'beauty' ),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-slider' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'beauty' ),
			'std'        => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Crimson Text',
				'font-weight'   => '400',
				'font-size'     => '40px',
				'line-height'   => '1.2',
				'color'         => '#2d2628',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-slider' === $posts_layout ) ? array(
			'id'       => 'mts_featured_slider_category_' . $unique_id,
			'type'     => 'select',
			'data'     => 'category',
			'multiple' => true,
			'args'     => array(
				'include_latest' => 1,
				'hide_empty'     => 0,
			),
			'title'    => esc_html__( 'Slider Category', 'beauty' ),
			'sub_desc' => esc_html__( 'Select a category for the slider.', 'beauty' ),
		) : null,

		( 'layout-slider' === $posts_layout ) ? array(
			'id'       => 'mts_featured_slider_num_' . $unique_id,
			'type'     => 'text',
			'class'    => 'small-text',
			'title'    => esc_html__( 'Number of posts', 'beauty' ),
			'sub_desc' => esc_html__( 'Enter the number of posts to show for the slider.', 'beauty' ),
			'args'     => array( 'type' => 'number' ),
			'std'      => '3',
		) : null,

		( 'layout-slider' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'beauty' ),
		) : null,

		( 'layout-slider' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'beauty' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'beauty' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'beauty' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'beauty' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'beauty' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'beauty' ),
							),
						),
					),
				),
				'disabled' => array(
					'author'  => array(
						'label'     => __( 'Author Name', 'beauty' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'beauty' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'beauty' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'beauty' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-slider' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'beauty' ),
			'sub_desc' => esc_html__( 'Post Meta Info margin.', 'beauty' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '30px',
				'left'   => '0',
			),
		) : null,

		( 'layout-slider' === $posts_layout ) ? array(
			'id'    => 'mts_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'beauty' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Karla',
				'font-weight'    => '400',
				'font-size'      => '13px',
				'color'          => '#5a4047',
				'letter-spacing' => '2px',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .slide-caption .post-info, .layout-' . $unique_id . ' .slide-caption .post-info a',
			),
		) : null,

		// Post Container.
		( 'layout-slider' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'beauty' ),
		) : null,

		( 'layout-slider' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'beauty' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'beauty' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'layout-slider' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'beauty' ),
			'sub_desc' => esc_html__( 'Select border', 'beauty' ),
		) : null,
		( 'layout-slider' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'beauty' ),
			'sub_desc' => esc_html__( 'Post margin.', 'beauty' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '0',
			),
		) : null,
		( 'layout-slider' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'beauty' ),
			'sub_desc' => esc_html__( 'Post padding.', 'beauty' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '60px',
			),
		) : null,

		( 'layout-slider' === $posts_layout ) ? array(
			'id'    => 'mts_featured_category_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'beauty' ),
			'std'   => array(
				'preview-text'  => 'Post Font',
				'preview-color' => 'light',
				'font-family'   => 'Crimson Text',
				'font-weight'   => '400',
				'font-size'     => '34px',
				'line-height'   => '36px',
				'color'         => '#2d2628',
				'css-selectors' => '.layout-' . $unique_id . ' .slide-caption .front-view-title a',
			),
		) : null,

		( 'layout-slider' === $posts_layout ) ? array(
			'id'    => 'mts_featured_category_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'beauty' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Karla',
				'font-weight'   => '400',
				'font-size'     => '16px',
				'line-height'   => '24px',
				'color'         => '#836d71',
				'css-selectors' => '.layout-' . $unique_id . ' .slide-caption .front-view-content',
			),
		) : null,

		/**
		 * Layout Default Settings
		 *
		 * @package Beauty
		 */

		// Section Title.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'mts_post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'beauty' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'beauty' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'beauty' ),
			'std'      => '0',
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'beauty' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'beauty' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'beauty' ),
				'center' => esc_html__( 'Center', 'beauty' ),
				'right'  => esc_html__( 'Right', 'beauty' ),
			),
			'std'        => 'left',
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'beauty' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'beauty' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'beauty' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'beauty' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '30px',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'beauty' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'beauty' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'beauty' ),
			'sub_desc'   => esc_html__( 'Select border', 'beauty' ),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'beauty' ),
			'std'        => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Crimson Text',
				'font-weight'   => '400',
				'font-size'     => '40px',
				'line-height'   => '1.2',
				'color'         => '#2d2628',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		// Meta info.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'beauty' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'beauty' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'beauty' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'beauty' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'beauty' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'beauty' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'beauty' ),
							),
						),
					),
				),
				'disabled' => array(
					'author'  => array(
						'label'     => __( 'Author Name', 'beauty' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'beauty' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'beauty' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'beauty' ),
							),
						),
					),
				),
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'beauty' ),
			'sub_desc' => esc_html__( 'Post Meta Info margin.', 'beauty' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '18px',
				'left'   => '0',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'beauty' ),
			'sub_desc' => esc_html__( 'Post Meta Info padding.', 'beauty' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'mts_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'beauty' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Karla',
				'font-weight'    => '400',
				'font-size'      => '13px',
				'color'          => '#5a4047',
				'letter-spacing' => '2px',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,

		// Post Container.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'beauty' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'beauty' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide readmore. Read More button will be shown on hover on posts.', 'beauty' ),
			'std'      => '1',
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'readmore_bg_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Read More Background Color', 'beauty' ),
			'sub_desc'   => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'beauty' ),
			'std'        => '#2d2628',
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'readmore_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'beauty' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'beauty' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'beauty' ),
			'sub_desc' => esc_html__( 'Select border', 'beauty' ),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'beauty' ),
			'sub_desc' => esc_html__( 'Post margin.', 'beauty' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '80px',
				'bottom' => '80px',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'beauty' ),
			'sub_desc' => esc_html__( 'Post padding.', 'beauty' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'mts_featured_category_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'beauty' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Crimson Text',
				'font-weight'   => '400',
				'font-size'     => '22px',
				'line-height'   => '28px',
				'color'         => '#2d2628',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'mts_featured_category_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'beauty' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Karla',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'line-height'   => '24px',
				'color'         => '#836d71',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout 1.
		 *
		 * @package Beauty
		 */

		// Section Title.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'mts_post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'beauty' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'beauty' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'beauty' ),
			'std'      => '1',
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'mts_post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'beauty' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'beauty' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'beauty' ),
				'center' => esc_html__( 'Center', 'beauty' ),
				'right'  => esc_html__( 'Right', 'beauty' ),
			),
			'std'        => 'left',
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'beauty' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'beauty' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'beauty' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'beauty' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '-28px',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'beauty' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'beauty' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'beauty' ),
			'sub_desc'   => esc_html__( 'Select border', 'beauty' ),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'beauty' ),
			'std'        => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Crimson Text',
				'font-weight'   => '400',
				'font-size'     => '100px',
				'line-height'   => '80px',
				'color'         => '#625c5e',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		// Meta info.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'beauty' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_image_position_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Post Image Position', 'beauty' ),
			'sub_desc' => esc_html__( 'Select image position to Left/ Right from here, content will be shown to Right/ Left from here.', 'beauty' ),
			'options'  => array(
				'image-left'  => esc_html__( 'Image Left', 'beauty' ),
				'image-right' => esc_html__( 'Image Right', 'beauty' ),
			),
			'std'      => 'image-left',
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'beauty' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'beauty' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'beauty' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'beauty' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'beauty' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'beauty' ),
							),
						),
					),
				),
				'disabled' => array(
					'author'  => array(
						'label'     => __( 'Author Name', 'beauty' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'beauty' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'beauty' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'beauty' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'beauty' ),
			'sub_desc' => esc_html__( 'Post Meta Info margin.', 'beauty' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '30px',
				'left'   => '0',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'mts_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'beauty' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Karla',
				'font-weight'    => '400',
				'font-size'      => '13px',
				'color'          => '#ffffff',
				'letter-spacing' => '2px',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,

		// Post Container.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'beauty' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'beauty' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide readmore.', 'beauty' ),
			'std'      => '0',
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'readmore_bg_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Read More Background Color', 'beauty' ),
			'sub_desc'   => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'beauty' ),
			'std'        => '#fec9c0',
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'readmore_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'beauty' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'beauty' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '#2d2628',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'beauty' ),
			'sub_desc' => esc_html__( 'Select border', 'beauty' ),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'beauty' ),
			'sub_desc' => esc_html__( 'Post margin.', 'beauty' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '150px',
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'beauty' ),
			'sub_desc' => esc_html__( 'Post padding.', 'beauty' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '85px',
				'right'  => '0',
				'bottom' => '75px',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'mts_featured_category_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'beauty' ),
			'std'   => array(
				'preview-text'  => 'Post Font',
				'preview-color' => 'dark',
				'font-family'   => 'Crimson Text',
				'font-weight'   => '400',
				'font-size'     => '34px',
				'line-height'   => '36px',
				'color'         => '#ffffff',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-title a',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'mts_featured_category_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'beauty' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'dark',
				'font-family'   => 'Karla',
				'font-weight'   => '400',
				'font-size'     => '16px',
				'line-height'   => '24px',
				'color'         => '#d8d7d7',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout 2.
		 *
		 * @package Beauty
		 */

		// Section Title.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'mts_post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'beauty' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'beauty' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'beauty' ),
			'std'      => '0',
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'mts_post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'beauty' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'beauty' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'beauty' ),
				'center' => esc_html__( 'Center', 'beauty' ),
				'right'  => esc_html__( 'Right', 'beauty' ),
			),
			'std'        => 'left',
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'beauty' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'beauty' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'beauty' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'beauty' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '30px',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'beauty' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'beauty' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'beauty' ),
			'sub_desc'   => esc_html__( 'Select border', 'beauty' ),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'beauty' ),
			'std'        => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Crimson Text',
				'font-weight'   => '400',
				'font-size'     => '40px',
				'line-height'   => '1.2',
				'color'         => '#2d2628',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		// Meta info.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'beauty' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'beauty' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'beauty' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'beauty' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'beauty' ),
							),
						),
					),
					'date'     => array(
						'label'     => esc_html__( 'Date', 'beauty' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'beauty' ),
							),
						),
					),
				),
				'disabled' => array(
					'author'  => array(
						'label'     => __( 'Author Name', 'beauty' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'beauty' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'beauty' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'beauty' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'beauty' ),
			'sub_desc' => esc_html__( 'Post Meta Info margin.', 'beauty' ),
			'std'      => array(
				'top'    => '10px',
				'right'  => '0',
				'bottom' => '16px',
				'left'   => '0',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'mts_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'beauty' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Karla',
				'font-weight'    => '400',
				'font-size'      => '13px',
				'color'          => '#5a4047',
				'letter-spacing' => '2px',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,

		// Post Container.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'beauty' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_sidebar_position_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Sidebar Position', 'beauty' ),
			'sub_desc' => esc_html__( 'Select sidebar position to Left/ Right from here, content will be shown to Right/ Left from here.', 'beauty' ),
			'options'  => array(
				'layout-2-sidebar-left'  => esc_html__( 'Left Sidebar', 'beauty' ),
				'layout-2-sidebar-right' => esc_html__( 'Right Sidebar', 'beauty' ),
			),
			'std'      => 'layout-2-sidebar-left',
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'beauty' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide readmore. Read More button will be shown on hover on posts.', 'beauty' ),
			'std'      => '1',
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'readmore_bg_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Read More Background Color', 'beauty' ),
			'sub_desc'   => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'beauty' ),
			'std'        => '#2d2628',
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'readmore_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'beauty' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'beauty' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'beauty' ),
			'sub_desc' => esc_html__( 'Select border', 'beauty' ),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'beauty' ),
			'sub_desc' => esc_html__( 'Post margin.', 'beauty' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '30px',
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'beauty' ),
			'sub_desc' => esc_html__( 'Post padding.', 'beauty' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '40px',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'mts_featured_category_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'beauty' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Crimson Text',
				'font-weight'   => '400',
				'font-size'     => '22px',
				'line-height'   => '28px',
				'color'         => '#2d2628',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'mts_featured_category_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'beauty' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Karla',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'line-height'   => '24px',
				'color'         => '#836d71',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout Partners.
		 *
		 * @package Beauty
		 */

		( 'layout-partners' === $posts_layout ) ? array(
			'id'        => 'partners_section_' . $unique_id,
			'type'      => 'group',
			'title'     => esc_html__( 'Partners Items', 'beauty' ),
			'groupname' => esc_html__( 'Partner Item', 'beauty' ),
			'subfields' => array(
				array(
					'id'    => 'partner_title',
					'type'  => 'text',
					'title' => esc_html__( 'Title', 'beauty' ),
				),
				array(
					'id'       => 'partner_image',
					'type'     => 'upload',
					'title'    => esc_html__( 'Image', 'beauty' ),
					'sub_desc' => esc_html__( 'Upload or select an image for partner. Recommended Size(190X70px)', 'beauty' ),
				),
				array(
					'id'       => 'partner_url',
					'type'     => 'text',
					'title'    => esc_html__( 'Link', 'beauty' ),
					'sub_desc' => esc_html__( 'Insert a link URL of partner', 'beauty' ),
					'std'      => '#',
				),
			),
		) : null,

		// Section Title.
		( 'layout-partners' === $posts_layout ) ? array(
			'id'    => 'mts_post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'beauty' ),
		) : null,

		( 'layout-partners' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'beauty' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'beauty' ),
			'std'      => '1',
		) : null,

		( 'layout-partners' === $posts_layout ) ? array(
			'id'         => 'partner_section_title_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Section Title', 'beauty' ),
			'sub_desc'   => esc_html__( 'Partners section title.', 'beauty' ),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'         => 'partners_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Partners Title Font', 'beauty' ),
			'std'        => array(
				'preview-text'  => 'Partners Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Crimson Text',
				'font-weight'   => '400',
				'font-size'     => '34px',
				'line-height'   => '40px',
				'color'         => '#2d2628',
				'css-selectors' => '.article.layout-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'beauty' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'beauty' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'         => 'post_title_shadow' . $unique_id,
			'type'       => 'switch',
			'title'      => esc_html__( 'Box Shadow', 'beauty' ),
			'sub_desc'   => esc_html__( 'Use this button to show or hide box shadow in post container.', 'beauty' ),
			'std'        => '1',
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'beauty' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'beauty' ),
			'left'       => false,
			'right'      => false,
			'std'        => array(
				'top'    => '0',
				'bottom' => '30px',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'beauty' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'beauty' ),
			'std'        => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'beauty' ),
			'sub_desc'   => esc_html__( 'Select border', 'beauty' ),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'mts_featured_category_title_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		// Post Container.
		( 'layout-partners' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'beauty' ),
		) : null,

		( 'layout-partners' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'beauty' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'beauty' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'beauty' ),
			'sub_desc' => esc_html__( 'Select border', 'beauty' ),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'beauty' ),
			'sub_desc' => esc_html__( 'Post margin.', 'beauty' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '50px',
			),
		) : null,
		( 'layout-partners' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'beauty' ),
			'sub_desc' => esc_html__( 'Post padding.', 'beauty' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '50px',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		/**
		 * Layout Category.
		 *
		 * @package Beauty
		 */

		( 'layout-category' === $posts_layout ) ? array(
			'id'        => 'cat_section_' . $unique_id,
			'type'      => 'group',
			'title'     => esc_html__( 'Category items', 'beauty' ),
			'sub_desc'  => esc_html__( 'Add category Item from here', 'beauty' ),
			'groupname' => esc_html__( 'Category item', 'beauty' ),
			'subfields' => array(
				array(
					'id'    => 'cat_section_title',
					'type'  => 'text',
					'title' => esc_html__( 'Title', 'beauty' ),
				),
				array(
					'id'       => 'cat_section_category',
					'type'     => 'select',
					'title'    => esc_html__( 'Category', 'beauty' ),
					'sub_desc' => esc_html__( 'Select a category for this section', 'beauty' ),
					'data'     => 'category',
				),
				array(
					'id'       => 'cat_section_image',
					'type'     => 'upload',
					'title'    => esc_html__( 'Image', 'beauty' ),
					'sub_desc' => esc_html__( 'Upload or select an image for category. Recommended Size(365X287px)', 'beauty' ),
				),
				array(
					'id'    => 'cat_section_background',
					'type'  => 'color',
					'title' => esc_html__( 'Select overlay color for your category', 'beauty' ),
					'args'  => array( 'opacity' => true ),
					'std'   => 'rgba(0, 0, 0, 0.3)',
				),
				array(
					'id'    => 'cat_section_hover_background',
					'type'  => 'color',
					'title' => esc_html__( 'Select overlay hover color for your category', 'beauty' ),
					'args'  => array( 'opacity' => true ),
					'std'   => 'rgba(0, 0, 0, 0.6)',
				),
			),
		) : null,

		// Post Container.
		( 'layout-category' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'beauty' ),
		) : null,

		( 'layout-category' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'beauty' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'beauty' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'layout-category' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'beauty' ),
			'sub_desc' => esc_html__( 'Select border', 'beauty' ),
		) : null,
		( 'layout-category' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'beauty' ),
			'sub_desc' => esc_html__( 'Post margin.', 'beauty' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '50px',
			),
		) : null,
		( 'layout-category' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'beauty' ),
			'sub_desc' => esc_html__( 'Post padding.', 'beauty' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '50px',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		/**
		 * Layout CTA
		 *
		 * @package Beauty
		 */

		( 'layout-cta' === $posts_layout ) ? array(
			'id'       => 'cta_size_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Section Size', 'beauty' ),
			'sub_desc' => esc_html__( 'Select the size of subscribe widget.', 'beauty' ),
			'options'  => array(
				'full'      => esc_html__( 'Full', 'beauty' ),
				'container' => esc_html__( 'Container', 'beauty' ),
			),
			'std'      => 'full',
		) : null,
		( 'layout-cta' === $posts_layout ) ? array(
			'id'    => 'subscribe_left_content_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'CTA Subscribe Widget', 'beauty' ),
		) : null,
		( 'layout-cta' === $posts_layout ) ? array(
			'id'       => 'subscribe_alignment_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'CTA Left Content Alignment', 'beauty' ),
			'sub_desc' => esc_html__( 'Alignment of CTA Left Content', 'beauty' ),
			'options'  => array(
				'left'   => esc_html__( 'Left', 'beauty' ),
				'center' => esc_html__( 'Center', 'beauty' ),
				'right'  => esc_html__( 'Right', 'beauty' ),
			),
			'std'      => 'left',
		) : null,
		( 'layout-cta' === $posts_layout ) ? array(
			'id'    => 'subscribe_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Title Typography', 'beauty' ),
			'std'   => array(
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Crimson Text',
				'font-weight'    => '400',
				'font-size'      => '34px',
				'line-height'    => '40px',
				'color'          => '#2d2628',
				'additional-css' => 'text-transform: capitalize;',
				'css-selectors'  => '.layout-' . $unique_id . ' .widget #wp-subscribe .title, .layout-' . $unique_id . ' .layout-cta .left-content h4',
			),
		) : null,
		( 'layout-cta' === $posts_layout ) ? array(
			'id'       => 'subscribe_input_background_' . $unique_id,
			'type'     => 'color',
			'title'    => esc_html__( 'Input Fields Background Color', 'beauty' ),
			'sub_desc' => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'beauty' ),
			'std'      => '#ffffff',
		) : null,
		( 'layout-cta' === $posts_layout ) ? array(
			'id'    => 'subscribe_input_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Input Fields Typography', 'beauty' ),
			'std'   => array(
				'preview-text'  => 'Input Fields Font',
				'preview-color' => 'dark',
				'font-family'   => 'Karla',
				'font-weight'   => '400',
				'font-size'     => '18px',
				'line-height'   => '24px',
				'color'         => '#8e8084',
				'css-selectors' => '.layout-' . $unique_id . ' .layout-cta #wp-subscribe input.email-field, .layout-' . $unique_id . ' .layout-cta #wp-subscribe input.name-field',
			),
		) : null,

		( 'layout-cta' === $posts_layout ) ? array(
			'id'    => 'subscribe_text_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Text Typography', 'beauty' ),
			'std'   => array(
				'preview-text'  => 'Text Font',
				'preview-color' => 'dark',
				'font-family'   => 'Karla',
				'font-weight'   => '400',
				'font-size'     => '16px',
				'line-height'   => '24px',
				'color'         => '#8e8084',
				'css-selectors' => '.layout-' . $unique_id . ' .layout-cta #wp-subscribe p.text, .layout-' . $unique_id . ' .subscribe-icons-container p, .layout-' . $unique_id . ' .layout-cta .left-content p',
			),
		) : null,
		( 'layout-cta' === $posts_layout ) ? array(
			'id'    => 'subscribe_small_text_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Small Text Typography', 'beauty' ),
			'std'   => array(
				'preview-text'  => 'Text Font',
				'preview-color' => 'dark',
				'font-family'   => 'Karla',
				'font-weight'   => '400',
				'font-size'     => '16px',
				'color'         => '#8e8084',
				'css-selectors' => '.layout-' . $unique_id . ' .layout-cta #sidebar .wp-subscribe-wrap p.footer-text, .layout-' . $unique_id . ' .layout-cta #sidebar .widget .wp-subscribe .wps-consent-wrapper',
			),
		) : null,

		// Right Content.
		( 'layout-cta' === $posts_layout ) ? array(
			'id'    => 'cta_right_content_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'CTA Right Content', 'beauty' ),
		) : null,

		( 'layout-cta' === $posts_layout ) ? array(
			'id'       => 'subscribe_right_alignment_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'CTA Right Content Alignment', 'beauty' ),
			'sub_desc' => esc_html__( 'Alignment of CTA Right Content', 'beauty' ),
			'options'  => array(
				'left'   => esc_html__( 'Left', 'beauty' ),
				'center' => esc_html__( 'Center', 'beauty' ),
				'right'  => esc_html__( 'Right', 'beauty' ),
			),
			'std'      => 'left',
		) : null,

		( 'layout-cta' === $posts_layout ) ? array(
			'id'    => 'cta_title_' . $unique_id,
			'type'  => 'text',
			'title' => esc_html__( 'CTA Title', 'beauty' ),
			'std'   => esc_html__( 'Learn how to advertise with us', 'beauty' ),
		) : null,

		( 'layout-cta' === $posts_layout ) ? array(
			'id'       => 'cta_url_' . $unique_id,
			'type'     => 'text',
			'title'    => esc_html__( 'CTA URL', 'beauty' ),
			'sub_desc' => esc_html__( 'Enter CTA URL.', 'beauty' ),
			'std'      => '#',
		) : null,

		( 'layout-cta' === $posts_layout ) ? array(
			'id'       => 'cta_button_bg_' . $unique_id,
			'type'     => 'color',
			'title'    => esc_html__( 'CTA Button Background', 'beauty' ),
			'sub_desc' => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'beauty' ),
			'std'      => '#2d2628',
		) : null,

		( 'layout-cta' === $posts_layout ) ? array(
			'id'    => 'cta_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'CTA Title Typography', 'beauty' ),
			'std'   => array(
				'preview-text'   => 'CTA Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Crimson Text',
				'font-weight'    => '400',
				'font-size'      => '34px',
				'line-height'    => '40px',
				'color'          => '#2d2628',
				'additional-css' => 'text-transform: capitalize;',
				'css-selectors'  => '.layout-' . $unique_id . ' .layout-cta .cta-title',
			),
		) : null,

		// Social Icons.

		( 'layout-cta' === $posts_layout ) ? array(
			'id'       => 'cta_social_icons_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'CTA Social Icons', 'beauty' ),
			'sub_desc' => esc_html__( 'Enable or disable CTA social icons with this option.', 'beauty' ),
			'std'      => '0',
		) : null,

		( 'layout-cta' === $posts_layout ) ? array(
			'id'         => 'cta_icon_title_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Title', 'beauty' ),
			'sub_desc'   => esc_html__( 'Social icon title.', 'beauty' ),
			'std'        => esc_html__( 'Follow Us', 'beauty' ),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'cta_social_icons_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		( 'layout-cta' === $posts_layout ) ? array(
			'id'         => 'cta_social_' . $unique_id,
			'title'      => esc_html__( 'CTA Social Icons', 'beauty' ),
			'sub_desc'   => esc_html__( 'Add Social Media icons in CTA section.', 'beauty' ),
			'type'       => 'group',
			'groupname'  => esc_html__( 'Social Icons', 'beauty' ), // Group name.
			'subfields'  => array(
				array(
					'id'    => 'cta_social_title',
					'type'  => 'text',
					'title' => esc_html__( 'Title', 'beauty' ),
				),
				array(
					'id'    => 'cta_social_icon',
					'type'  => 'icon_select',
					'title' => esc_html__( 'Icon', 'beauty' ),
				),
				array(
					'id'    => 'cta_social_link',
					'type'  => 'text',
					'title' => esc_html__( 'URL', 'beauty' ),
				),
				array(
					'id'    => 'cta_social_color',
					'type'  => 'color',
					'title' => esc_html__( 'Icon color', 'beauty' ),
				),
				array(
					'id'    => 'cta_social_hover_color',
					'type'  => 'color',
					'title' => esc_html__( 'Icon hover color', 'beauty' ),
				),
				array(
					'id'    => 'cta_social_margin',
					'type'  => 'margin',
					'title' => esc_html__( 'Margin', 'beauty' ),
				),
				array(
					'id'    => 'cta_social_padding',
					'type'  => 'margin',
					'title' => esc_html__( 'Padding', 'beauty' ),
				),
			),
			'std'        => array(
				'facebook'  => array(
					'group_title'            => 'Facebook',
					'group_sort'             => '1',
					'cta_social_title'       => 'Facebook',
					'cta_social_icon'        => 'facebook-square',
					'cta_social_link'        => '#',
					'cta_social_color'       => '#2d2628',
					'cta_social_hover_color' => beauty_get_settings( 'mts_color_scheme' ),
					'cta_social_margin'      => array(
						'top'    => '0',
						'right'  => '22px',
						'bottom' => '0',
						'left'   => '0',
					),
					'cta_social_padding'     => array(
						'top'    => '0',
						'right'  => '0',
						'bottom' => '0',
						'left'   => '0',
					),
				),
				'youtube'   => array(
					'group_title'            => 'Youtube',
					'group_sort'             => '1',
					'cta_social_title'       => 'Youtube',
					'cta_social_icon'        => 'youtube',
					'cta_social_link'        => '#',
					'cta_social_color'       => '#2d2628',
					'cta_social_hover_color' => beauty_get_settings( 'mts_color_scheme' ),
					'cta_social_margin'      => array(
						'top'    => '0',
						'right'  => '22px',
						'bottom' => '0',
						'left'   => '0',
					),
					'cta_social_padding'     => array(
						'top'    => '0',
						'right'  => '0',
						'bottom' => '0',
						'left'   => '0',
					),
				),
				'twitter'   => array(
					'group_title'            => 'Twitter',
					'group_sort'             => '3',
					'cta_social_title'       => 'Twitter',
					'cta_social_icon'        => 'twitter',
					'cta_social_link'        => '#',
					'cta_social_color'       => '#2d2628',
					'cta_social_hover_color' => beauty_get_settings( 'mts_color_scheme' ),
					'cta_social_margin'      => array(
						'top'    => '0',
						'right'  => '22px',
						'bottom' => '0',
						'left'   => '0',
					),
					'cta_social_padding'     => array(
						'top'    => '0',
						'right'  => '0',
						'bottom' => '0',
						'left'   => '0',
					),
				),
				'pinterest' => array(
					'group_title'            => 'Pinterest',
					'group_sort'             => '4',
					'cta_social_title'       => 'Pinterest',
					'cta_social_icon'        => 'pinterest',
					'cta_social_link'        => '#',
					'cta_social_color'       => '#2d2628',
					'cta_social_hover_color' => beauty_get_settings( 'mts_color_scheme' ),
					'cta_social_margin'      => array(
						'top'    => '0',
						'right'  => '22px',
						'bottom' => '0',
						'left'   => '0',
					),
					'cta_social_padding'     => array(
						'top'    => '0',
						'right'  => '0',
						'bottom' => '0',
						'left'   => '0',
					),
				),
				'instagram' => array(
					'group_title'            => 'Instagram',
					'group_sort'             => '5',
					'cta_social_title'       => 'Instagram',
					'cta_social_icon'        => 'instagram',
					'cta_social_link'        => '#',
					'cta_social_color'       => '#2d2628',
					'cta_social_hover_color' => beauty_get_settings( 'mts_color_scheme' ),
					'cta_social_margin'      => array(
						'top'    => '0',
						'right'  => '0',
						'bottom' => '0',
						'left'   => '0',
					),
					'cta_social_padding'     => array(
						'top'    => '0',
						'right'  => '0',
						'bottom' => '0',
						'left'   => '0',
					),
				),
			),
			'dependency' => array(
				'relation' => 'and',
				array(
					'field'      => 'cta_social_icons_' . $unique_id,
					'value'      => '1',
					'comparison' => '==',
				),
			),
		) : null,

		// Post Container.
		( 'layout-cta' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'beauty' ),
		) : null,

		( 'layout-cta' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'beauty' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'beauty' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '#ffffff',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'layout-cta' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'beauty' ),
			'sub_desc' => esc_html__( 'Select border', 'beauty' ),
		) : null,
		( 'layout-cta' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'beauty' ),
			'sub_desc' => esc_html__( 'Post margin.', 'beauty' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '30px',
			),
		) : null,
		( 'layout-cta' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'beauty' ),
			'sub_desc' => esc_html__( 'Post padding.', 'beauty' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '40px',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		/**
		 * Layout Ad.
		 *
		 * @package Beauty
		 */

		( 'layout-ad' === $posts_layout ) ? array(
			'id'       => 'adcode_' . $unique_id,
			'type'     => 'ace_editor',
			'mode'     => 'html',
			'title'    => esc_html__( 'Ad Code', 'beauty' ),
			'sub_desc' => esc_html__( 'Paste your Adsense, BSA or other ad code here to show ads.', 'beauty' ),
		) : null,

		// Post Container.
		( 'layout-ad' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'beauty' ),
		) : null,

		( 'layout-ad' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'beauty' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'beauty' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'layout-ad' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'beauty' ),
			'sub_desc' => esc_html__( 'Select border', 'beauty' ),
		) : null,
		( 'layout-ad' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'beauty' ),
			'sub_desc' => esc_html__( 'Post margin.', 'beauty' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '50px',
			),
		) : null,
		( 'layout-ad' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'beauty' ),
			'sub_desc' => esc_html__( 'Post padding.', 'beauty' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '50px',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

	);
endforeach;
